@@ -38,8 +38,10 @@ local_pandoc_convert <- function(text, from = "markdown", options = NULL, ..., .
   skip_if_not_pandoc()
   rmd <- local_rmd_file(text)
   out <- withr::local_tempfile(.local_envir = .env)
-  rmarkdown::pandoc_convert(rmd, from = from, output = out,
-                            options = c("--wrap", "preserve", options), ...)
+  rmarkdown::pandoc_convert(rmd,
+    from = from, output = out,
+    options = c("--wrap", "preserve", options), ...
+  )
   xfun::read_utf8(out)
 }
 
